<script src="{{ url_for('static', filename='bower/jquery/dist/jquery.js') }}" type="text/javascript"></script>

<script src="{{ url_for('static', filename='bower/bootstrap/dist/js/bootstrap.min.js') }}" type="text/javascript"></script>
<script src="{{ url_for('static', filename='bower/bootstrap3-typeahead/bootstrap3-typeahead.js') }}" type="text/javascript"></script>
<script src="{{ url_for('static', filename='bower/leaflet/dist/leaflet.js') }}" type="text/javascript"></script>
<script src="{{ url_for('static', filename='bower/turfjs/turf.min.js') }}" type="text/javascript"></script>
<script src="{{ url_for('static', filename='bower/highcharts/highcharts.js') }}" type="text/javascript"></script>
