<link media="screen" rel="stylesheet" type="text/css"
    href="{{ url_for('static', filename='bower/bootstrap/dist/css/bootstrap.min.css') }}" />
<link media="screen" rel="stylesheet" type="text/css"
      href="{{ url_for('static', filename='bower/leaflet/dist/leaflet.css') }}" />
