{% extends 'layout.html' %}

{% block content %}

<h2>Pyris: Insee IRIS Geolocalizer</h2>

<ol class="breadcrumb">
  <li><a href="/">Home</a></li>
</ol>


<h3>Description</h3>

<p>
  <u>Find an IRIS code from a French address</u>.</br></br>
</p>

<p>
  <a href="http://www.insee.fr/fr/methodes/default.asp?page=definitions/iris.htm">IRIS</a>
  is a a code related to a district provided
  by <a href="https://fr.wikipedia.org/wiki/Institut_national_de_la_statistique_et_des_%C3%A9tudes_%C3%A9conomiques">Insee</a>,
  the French National Institute of Statistics and Economic Studies. Thus, it's
  possible to have some statistical indicators for more than 50,000 different
  IRIS (resp. districts).</br>

  The longitude/latitude coordinates are retrieved thanks to
  the <a href="https://adresse.data.gouv.fr/about/">National Address French
  Base</a> and its great <a href="https://adresse.data.gouv.fr/api/">API</a>.
</p>

<h3>Interactive Map</h3>

<p>
  Search an IRIS from an address and visualize it on an <a href="/map">interactive map!!</a>
</p>

<h3>Some stats</h3>

<p>
  For each IRIS, you can find some population, employment and housing stats (by age
  or by sex). There data came from Insee.</p>

<p>Here an example in
  the <a href="/iris/751010301">first Paris district "Palais Royal"</a>.
</p>


<h3>Data</h3>

<p>
Find the raw data at
the <a href="https://www.data.gouv.fr/fr/datasets/contour-des-iris-insee-tout-en-un/">Open
Data French gouvernment website</a> and
the <a href="https://www.insee.fr/fr/statistiques">Insee</a> website.
</p>


<h3>Code</h3>

<p>
You can find the source code of this project on
the <a href="https://github.com/garaud/pyris">pyris Github page</a>. It's
powered by Python, Flask and PostgreSQL.
</p>


<h3>Access</h3>

<p>
  Examples:

  <ul>
    <li>Get some information from an IRIS code: <tt>URL/iris/0508</tt></li>
    <li>Retrieve the IRIS code from an address: <tt>URL/search/?q=place de
    la bourse Bordeaux</tt></li>
  </ul>

  You also can read and try <a href="/doc/">the REST API</a> generated
  by <a href="https://flask-restplus.readthedocs.org/en/stable/">Flask-RESTPlus</a>
  and <a href="http://swagger.io/">Swagger</a>.
</p>


{% endblock %}
